@@ -13,7 +13,9 @@
 
 # Default to Horizons test settings to avoid any missing keys
 import heat_dashboard.enabled
+import openstack_dashboard.enabled
 
+import openstack_dashboard.enabled  # noqa: F811
 from openstack_dashboard.test.settings import *  # noqa: F403,H303
 
 from openstack_dashboard.utils import settings
